ug_gemeinde
===========

Adressverwaltung für Gemeinden.

Das Programm wurde und wird von Ulrich Goebel speziell für die Anforderungen von kirchlichen Gemeinden entwickelt.

Das hier verfügbare Paket beinhaltet ausschließlich die GUI für diese Adressverwaltung. Die Daten werden in einer PostgreSQL-Datenbank gehalten, die auf einem eigenen Server läuft. Auswertungen, also PDFs zum Ausdrucken von Adresslisten u.a. werden ebenso auf diesem Server durch einen Cron-Job regelmäßig hergestellt und über eine Nextcloud bereitgestellt.

Durch die spezielle Architektur ist das Paket kaum für jedermann brauchbar. Falls es aber Interesse gibt, kann man sich gerne an Ulrich Goebel wenden (ulrich@fam-goebel.de).
